/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial developer(s): Florent BENOIT & Ludovic BERT
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.mail;


//import java
import java.rmi.RemoteException;
import java.util.Properties;

//import objectweb
import org.objectweb.jonas.mail.factory.JMailSession;
import org.objectweb.jonas.mail.factory.JMailMimePartDS;


/**
 * This interface provides a description for the mail service management.
 * @author Ludovic Bert
 * @author Florent Benoit
 */
public interface MailServiceImplMBean { 

    /**
     * Create a mail factory with the specified properties and register it 
     * into the registry.
     * @param props the properties used to configure the mail factory.
     * @throws MailServiceException if the creation or the registration of 
     * the factory failed.
     * @throws RemoteException if rmi call failed.
     */
    public void createMailFactoryMBean(Properties props) 
        throws RemoteException, MailServiceException;

    /**
     * Unregister the binding factory with the given name.
     * @param name the name of the factory.
     * @throws MailServiceException if the unregistration of the 
     * factory failed.
     * @throws RemoteException if rmi call failed.
     */
    public void unbindMailFactoryMBean(String name) 
        throws RemoteException, MailServiceException;

    /**
     * Get the list of the registered JMailSessionFactories.
     * @return the list of the registered JMailSessionFactories.
     * @throws RemoteException if rmi call failed.
     */
    public JMailSession[] getJMailSessionFactoriesMBean() throws RemoteException;

    /**
     * Get the list of the registered JMailMimePartDSFactories.
     * @return the list of the registered JMailMimePartDSFactories.
     * @throws RemoteException if rmi call failed.
     */
    public JMailMimePartDS[] getJMailMimePartDSFactoriesMBean() throws RemoteException;

}
